#!/bin/bash
set -e

# Generate configuration report in Excel
dpbuddy configReport -dir confrep -persisted -objects "WSGatew.*, .*Firewall.*:test.*" -domains ".*" -excel -reportFileName DPReport.xlsx -excludeElements "UserInfo"
# Generate configuration report with differences
dpbuddy configReport -dir confrep -persisted -objects "WSGatew.*, .*Firewall.*:test.*" -domains ".*" -excel -reportFileName DPReport.xlsx -diff
# Check the status of firewall and proxy objects
dpbuddy listObjects -objects "XMLF.*,WSGateway" -domainPatterns ".*"
# This will print the status of all services,
# including their ports in all domains
dpbuddy listServices -domainPatterns ".*"
# Check the filesystem status
dpbuddy status -class FilesystemStatus
# Check the status of the LBG group,
# fail if any member of test-group is not in 'up' state
dpbuddy assertStatus -class "LoadBalancerStatus2" -expression "(Group!='test-group' || Health=='up')"
# check all objects
dpbuddy assertState -domains "dpbuddy.*"
# all except ISAMRuntime
dpbuddy assertState -objects ".*" -exclude "ISAMRuntime"
# Check all WS proxy, XML firewalls, XML managers, except default-wsrr
dpbuddy assertState -objects "WSGateway, XML.*" -exclude "XMLM.*:default-.*"
# Check all WS proxy, XML firewalls, make sure they're also in the list of active services
dpbuddy assertState -objects "WSGateway, XMLF.*" -activeService
# Or check active services separately
dpbuddy assertActiveService -objects "WSGateway, XMLF.*"

dpbuddy assertOpenPorts -ports "9090, 5550" -domain default
# Test remote hosts/ports from DataPower
dpbuddy testTcp -hostPort "google.com:443,google.com:80"


